@@ -114,7 +114,7 @@ class UserAdmin(BaseUserAdmin):
     change_user_password_template = None
     fieldsets = (
         (None, {'fields': ('email', 'password')}),
-        (_('Personal info'), {'fields': ('first_name', 'last_name')}),
+        (_('Personal info'), {'fields': ('first_name', 'last_name', 'phone_number')}),
         (_('Permissions'), {'fields': ('is_active', 'is_staff', 'is_superuser', 'is_email_verified',
                                        'groups', 'user_permissions')}),
         (_('Important dates'), {'fields': ('last_login', 'date_joined')}),
@@ -129,7 +129,7 @@ class UserAdmin(BaseUserAdmin):
     add_form = UserCreationForm2
     form = UserChangeForm
 
-    list_display = ('email', 'first_name', 'last_name', 'is_staff')
+    list_display = ('email', 'first_name', 'last_name', 'phone_number', 'is_staff')
     list_filter = ('is_staff', 'is_superuser', 'is_active', 'is_email_verified', 'groups')
     search_fields = ('first_name', 'last_name', 'email')
     ordering = ('email',)
