@@ -29,7 +29,7 @@ class TesterMiddleware:
         signer = TimestampSigner()
         request.session['features'] = []
         if not (request.path.startswith('/admin/')
-                or request.path in ['/healthcheck', '/robots.txt', '/troubleshoot']
+                or request.path in ['/healthcheck', '/robots.txt', '/troubleshoot', '/account/verify']
                 or (exceptions_re and exceptions_re.match(request.path))
                 or passkey in settings.PRIVATE_URL_ACCESS_KEYS
                 ):
